@@ -55,6 +55,7 @@ bed_reldist <- function(x, y, detail = FALSE) {
   grp_indexes <- shared_group_indexes(x, y)
 
   res <- dist_impl(x, y, grp_indexes$x, grp_indexes$y, distcalc = "reldist")
+  res <- tibble::as_tibble(res)
 
   if (detail) {
     return(res)
@@ -62,12 +63,12 @@ bed_reldist <- function(x, y, detail = FALSE) {
 
   res[[".reldist"]] <- floor(res[[".reldist"]] * 100) / 100
   nr <- nrow(res)
-  res <- group_by(res, .reldist)
+  res <- group_by(res, .data[[".reldist"]])
   res <- summarize(
     res,
     .counts = n(),
     .total = nr,
-    .freq = .counts / .total
+    .freq = .data[[".counts"]] / .data[[".total"]]
   )
   res
 }
