@@ -49,7 +49,11 @@ check_interval <- function(x) {
   }
 
   # Ensure start/end are doubles for C++ code (handles large coordinates)
-  x <- mutate(x, start = as.numeric(.data[["start"]]), end = as.numeric(.data[["end"]]))
+  x <- mutate(
+    x,
+    start = as.numeric(.data[["start"]]),
+    end = as.numeric(.data[["end"]])
+  )
 
   x
 }
