@@ -1,3 +1,6 @@
+#' @keywords internal
+"_PACKAGE"
+
 #' valr: genome interval arithmetic in R
 #'
 #' valr provides tools to read and manipulate intervals and signals on a genome
@@ -10,11 +13,11 @@
 #' @author Jay Hesselberth <jay.hesselberth@@gmail.com>
 #' @author Kent Riemondy <kent.riemondy@@gmail.com>
 #'
-#' @docType package
 #' @name valr
 #'
 #' @seealso Report bugs at \url{https://github.com/rnabioco/valr/issues}
 #'
+## usethis namespace: start
 #' @useDynLib valr, .registration = TRUE
 #' @importFrom tibble tribble as_tibble is_tibble
 #' @importFrom readr read_tsv col_integer col_character col_double
@@ -26,4 +29,9 @@
 #' @importFrom lifecycle deprecated
 #' @import ggplot2
 #' @import dplyr
-"_PACKAGE"
+#' @importFrom lifecycle deprecated
+## usethis namespace: end
+
+## mockable bindings: start
+## mockable bindings: end
+NULL
