@@ -59,6 +59,5 @@ test_that("read bigwig", {
 
 
 test_that("read gtf", {
-  expect_error(read_gtf(gtf_path))
-  # expect_equal(ncol(x), 26)
+  expect_snapshot(read_gtf(gtf_path), error = TRUE)
 })
